PALM-meteo: palmmeteo.config Namespace Reference

PALM-meteo

Classes | Functions | Variables
palmmeteo.config Namespace Reference

## Classes
class | ConfigError
class | ConfigObj

## Functions
def | parse_duration (section, item, value=None)
def | load_config (argv)

## Variables
dictionary | duration_units
| cfg = ConfigObj()

## Function Documentation

## ◆ load_config()

def palmmeteo.config.load_config | ( |  | argv | ) |

    Loads all configuration.

    Configuration is loaded in this order:
    1) initial configuration values
    2) configfile
    3) command-line options
    Each step may overwrite values from previous steps.

## ◆ parse_duration()

def palmmeteo.config.parse_duration | ( |  | section,
|  |  | item,
|  |  | value = `None`
| ) |  |

## Variable Documentation

## ◆ cfg

palmmeteo.config.cfg = ConfigObj()

## ◆ duration_units

dictionary palmmeteo.config.duration_units

Initial value:
1= {
2 'd': 'days',
3 'h': 'hours',
4 'm': 'minutes',
5 's': 'seconds',
6 }